@@ -22,6 +22,11 @@ MAINTAINABILITY_ORIGIN_CLASS = 'RAD100'
 class RadonInspector(BaseInspector):
     inspector_type = InspectorType.RADON
 
+    # We don't support in-memory inspection for Radon yet
+    @classmethod
+    def inspect_in_memory(cls, code: str, config: Dict[str, Any]) -> List[BaseIssue]:
+        return []
+
     @classmethod
     def inspect(cls, path: Path, config: Dict[str, Any]) -> List[BaseIssue]:
         mi_command = [
