@@ -3,7 +3,11 @@ from typing import List, Optional
 
 from hyperstyle.src.python.review.application_config import ApplicationConfig
 from hyperstyle.src.python.review.common.language import Language
-from hyperstyle.src.python.review.common.parallel_runner import inspect_in_parallel
+from hyperstyle.src.python.review.common.parallel_runner import (
+    inspect_in_parallel,
+    run_inspector,
+    run_inspector_in_memory,
+)
 from hyperstyle.src.python.review.inspectors.checkstyle.checkstyle import CheckstyleInspector
 from hyperstyle.src.python.review.inspectors.detekt.detekt import DetektInspector
 from hyperstyle.src.python.review.inspectors.eslint.eslint import ESLintInspector
@@ -24,7 +28,12 @@ from hyperstyle.src.python.review.reviewers.utils.issues_filter import (
     filter_low_measure_issues,
     group_issues_by_difficulty,
 )
-from hyperstyle.src.python.review.reviewers.utils.metadata_exploration import FileMetadata, Metadata
+from hyperstyle.src.python.review.reviewers.utils.metadata_exploration import (
+    FileMetadata,
+    InMemoryMetadata,
+    Metadata,
+    ProjectMetadata,
+)
 
 LANGUAGE_TO_INSPECTORS = {
     Language.PYTHON: [
@@ -49,26 +58,39 @@ LANGUAGE_TO_INSPECTORS = {
 }
 
 
-def perform_language_review(metadata: Metadata, config: ApplicationConfig, language: Language) -> GeneralReviewResult:
+def _inspect_code(metadata: Metadata, config: ApplicationConfig, language: Language) -> Optional[List[BaseIssue]]:
     inspectors = LANGUAGE_TO_INSPECTORS[language]
+    if isinstance(metadata, InMemoryMetadata):
+        return inspect_in_parallel(run_inspector_in_memory, metadata.code, config, inspectors)
+    return inspect_in_parallel(run_inspector, metadata.path, config, inspectors)
 
-    issues = inspect_in_parallel(metadata.path, config, inspectors)
+
+def perform_language_review(metadata: Metadata, config: ApplicationConfig, language: Language) -> GeneralReviewResult:
+    issues = _inspect_code(metadata, config, language)
     if issues:
         issues = filter_low_measure_issues(issues, language)
 
         if not config.allow_duplicates:
             issues = filter_duplicate_issues(issues)
 
+    current_files = None
     if isinstance(metadata, FileMetadata):
-        files_metadata = [metadata]
+        current_files = [metadata.path]
         issues = filter_out_of_range_issues(issues, config.start_line, config.end_line)
-    else:
-        files_metadata = metadata.language_to_files[language]
+    elif isinstance(metadata, ProjectMetadata):
+        current_files = metadata.language_to_files[language]
 
     file_path_to_issues = defaultdict(list)
     for issue in issues:
         file_path_to_issues[issue.file_path].append(issue)
 
+    if current_files is None:
+        files = file_path_to_issues.keys()
+        if len(files) == 0:
+            current_files = []
+        else:
+            current_files = files
+
     previous_issues = get_previous_issues_by_language(config.history, language)
     categorize(previous_issues, issues)
 
@@ -83,12 +105,12 @@ def perform_language_review(metadata: Metadata, config: ApplicationConfig, langu
     }
 
     file_review_results = []
-    for file_metadata in files_metadata:
-        file_issues = file_path_to_issues[file_metadata.path]
+    for file in current_files:
+        file_issues = file_path_to_issues[file]
         file_issues_by_difficulty = group_issues_by_difficulty(file_issues)
 
         code_statistics_by_difficulty = {
-            difficulty: gather_code_statistics(file_issues, file_metadata.path)
+            difficulty: gather_code_statistics(file_issues, file)
             for difficulty, file_issues in file_issues_by_difficulty.items()
         }
 
@@ -110,7 +132,7 @@ def perform_language_review(metadata: Metadata, config: ApplicationConfig, langu
             general_quality_by_difficulty[difficulty] = general_quality_by_difficulty[difficulty].merge(quality)
 
         file_review_results.append(
-            FileReviewResult(quality_by_difficulty, punisher_by_difficulty, file_issues, file_metadata.path),
+            FileReviewResult(quality_by_difficulty, punisher_by_difficulty, file_issues, file),
         )
 
     return GeneralReviewResult(
