@@ -12,6 +12,8 @@ SPRING_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'spring'
 
 JS_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'js'
 
+GO_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'go'
+
 PYTHON_AST_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'python_ast'
 
 CHECKSTYLE_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'checkstyle'
@@ -25,3 +27,5 @@ PYLINT_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'pylint'
 DETEKT_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'detekt'
 
 ESLINT_DATA_FOLDER = CURRENT_TEST_DATA_FOLDER / 'eslint'
+
+GOLANG_LINT_FOLDER = CURRENT_TEST_DATA_FOLDER / 'golang_lint'
